@@ -1,17 +1,23 @@
 `anova.cca` <-
-    function (object, alpha = 0.05, beta = 0.01, step = 100, perm.max = 10000, 
+    function (object, alpha = 0.05, beta = 0.01, step = 100, perm.max = 9999, 
               by = NULL, ...) 
 {
     if (is.null(object$CA))
         stop("Impossible analysis: no residual unconstrained component")
     if (is.null(object$CCA))
         stop("Nothing to analyse: no constrained component")
+    perm.max <- max(step-1, perm.max)
     if (!is.null(by)) {
-        by <- match.arg(by, c("axis", "terms"))
+        by <- match.arg(by, c("axis", "terms", "margin"))
         if (by == "axis") 
             sol <- anova.ccabyaxis(object, alpha = alpha, beta = beta, 
                                    step = step, perm.max = perm.max, by = NULL, 
                                    ...)
+        else if (by == "margin") {
+            sol <- anova.ccabymargin(object, alpha = alpha, beta = beta,
+                                     step = step, perm.max = perm.max,
+                                     by = NULL, ...)
+            }
         else {
             mf <- match.call(expand.dots = FALSE)
             if (!is.null(mf$...) && any(k <- pmatch(names(mf$...), 
@@ -27,17 +33,18 @@
     unsure <- TRUE
     hits <- 0
     while (unsure && nperm < perm.max) {
-        tst <- permutest.cca(object, step, ...)
+        adj <- as.numeric(nperm == 0)
+        tst <- permutest.cca(object, step - adj, ...)
         if (is.null(seed)) 
             seed <- tst$Random.seed
-        nperm <- nperm + step
+        nperm <- nperm + step - adj
         hits <- hits + sum(tst$F.perm >= tst$F.0)
         fork <- qbinom(betaq, nperm, alpha)
         if (hits < fork[1] || hits > fork[2]) 
             unsure <- FALSE
     }
     Fval <- c(tst$F.0, NA)
-    Pval <- c(hits/nperm, NA)
+    Pval <- c((hits+1)/(nperm+1), NA)
     nperm <- c(nperm, NA)
     table <- data.frame(tst$df, tst$chi, Fval, nperm, Pval)
     is.rda <- inherits(object, "rda")
@@ -52,3 +59,4 @@
     structure(table, heading = c(head, mod), Random.seed = seed, 
               class = c("anova.cca", "anova", "data.frame"))
 }
+
